dubo
====

dubo is a client for running LLMs against DataFrames and other 2D data.

It is currently in a beta release. To join the beta, you can check out the [documentation](https://docs.dubo.gg).

## Generate API Client

An api client can be generated to access the dubo API, it is located in the `/dubo/api_client` folder:

```shell
just generate-api-client
```

More info can be found in the README file inside the `api-client-generator` folder.

## Generate Documentation

```shell
just generate-doc
```
